@@ -1,6 +1,5 @@
-from typing import Dict, Tuple
+from typing import Dict, Tuple, Optional
 from pathlib import Path
-from abc import ABC, abstractmethod
 
 import asyncio
 
@@ -11,7 +10,7 @@ from ._base import InotifyBase
 __all__ = ('Minotaur',)
 
 
-class Notification(ABC):
+class Notification:
     __slots__ = (
         '_path',
         '_type',
@@ -48,7 +47,7 @@ class Notification(ABC):
     def path(self) -> Path:
         return self._path
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         t = self._isdir and 'dir' or 'file'
         return f'{type(self).__name__}({self._type.name} {t} {self._path})'
 
@@ -80,8 +79,12 @@ class Minotaur(InotifyBase):
     _wdmap: Dict[int, Path]
     _cmap: Dict[Tuple[int, int], Event]
 
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
+    def __init__(self,
+                 blocking: bool = True,
+                 cloexec: bool = True,
+                 loop: Optional[asyncio.AbstractEventLoop] = None,
+                 ) -> None:
+        super().__init__(blocking, cloexec, loop)
         self._wdmap = {}
         self._cmap = {}
 
@@ -102,7 +105,7 @@ class Minotaur(InotifyBase):
         else:
             del self._wdmap[wd]
 
-    def _resolve_path(self, wd: int, name: Path):
+    def _resolve_path(self, wd: int, name: Path) -> Path:
         try:
             base_dir = self._wdmap[wd]
         except KeyError:
